summaryrefslogtreecommitdiffstats
path: root/ash/dip_unittest.cc
diff options
context:
space:
mode:
authoroshima@chromium.org <oshima@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-09-23 23:19:15 +0000
committeroshima@chromium.org <oshima@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-09-23 23:19:15 +0000
commita60fc623767a05d5bdc28806bcad2cd2ec6b68c6 (patch)
tree6afee5839acc56d6d8817696498d0f5f590e8fc4 /ash/dip_unittest.cc
parentec860d3e0cbeb59420b3e52634443e37db53249b (diff)
downloadchromium_src-a60fc623767a05d5bdc28806bcad2cd2ec6b68c6.zip
chromium_src-a60fc623767a05d5bdc28806bcad2cd2ec6b68c6.tar.gz
chromium_src-a60fc623767a05d5bdc28806bcad2cd2ec6b68c6.tar.bz2
Rename DisplayInfo::bounds_in_pixel -> bounds_in_native
because "pixel" is virtual and no longer correspond to physical pixel. Update comments. BUG=273142 R=derat@chromium.org TBR=mukai@chromium.org Review URL: https://codereview.chromium.org/23757064 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@224831 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'ash/dip_unittest.cc')
-rw-r--r--ash/dip_unittest.cc6
1 files changed, 3 insertions, 3 deletions
diff --git a/ash/dip_unittest.cc b/ash/dip_unittest.cc
index 4a6745a..59020e8 100644
--- a/ash/dip_unittest.cc
+++ b/ash/dip_unittest.cc
@@ -53,7 +53,7 @@ TEST_F(DIPTest, WorkArea) {
// The |bounds_in_pixel()| should report bounds in pixel coordinate.
EXPECT_EQ("1,1 2000x1800",
- display_info_2x.bounds_in_pixel().ToString());
+ display_info_2x.bounds_in_native().ToString());
// Aura and views coordinates are in DIP, so they their bounds do not change.
EXPECT_EQ("0,0 1000x900", display_2x.bounds().ToString());
@@ -90,9 +90,9 @@ TEST_F(DIPTest, WorkAreaForLegacyShelfLayout) {
const internal::DisplayInfo display_info_2x =
Shell::GetInstance()->display_manager()->GetDisplayInfo(display_2x.id());
// The |bounds_in_pixel()| should report bounds in pixel coordinate.
EXPECT_EQ("1,1 2000x1800",
- display_info_2x.bounds_in_pixel().ToString());
+ display_info_2x.bounds_in_native().ToString());
// Aura and views coordinates are in DIP, so they their bounds do not change.
EXPECT_EQ("0,0 1000x900", display_2x.bounds().ToString());
@@ -90,9 +90,9 @@ TEST_F(DIPTest, WorkAreaForLegacyShelfLayout) {
const internal::DisplayInfo display_info_2x =
Shell::GetInstance()->display_manager()->GetDisplayInfo(display_2x.id());
- // The |bounds_in_pixel()| should report bounds in pixel coordinate.
+ // The |bounds_in_native()| should report bounds in pixel coordinate.
EXPECT_EQ("1,1 2000x1800",